# CHANGELOG

<!-- version list -->

## v1.1.0 (2026-03-23)

### Chores

- Add widoco docs gen
  ([`3f22615`](https://github.com/celine-eu/ontologies/commit/3f226157daaa35afb3e6d365514a59823808cf19))

- Add widoco docs, review strucuture for releases
  ([`ae50d89`](https://github.com/celine-eu/ontologies/commit/ae50d8982153145cb4eb9092603991a1c30aaa53))

- **deps**: Bump rdflib from 7.5.0 to 7.6.0
  ([`f2daefe`](https://github.com/celine-eu/ontologies/commit/f2daefe6191974a576f0fde774513f8728ca12ec))

- **deps**: Bump typer from 0.21.1 to 0.24.1
  ([`bf5287c`](https://github.com/celine-eu/ontologies/commit/bf5287c7f348c86b3743afdb4c84fecdf0e277d8))

### Continuous Integration

- Bump peter-evans/repository-dispatch in the actions group
  ([`ff34b9a`](https://github.com/celine-eu/ontologies/commit/ff34b9aea5afd5324b1641ba9f7945384311fadf))

### Features

- Separate mapper and cli subpackages
  ([`fafe818`](https://github.com/celine-eu/ontologies/commit/fafe81842b1f551a12bd37bfe7522ef4018d3fe8))


## v1.0.1 (2026-03-22)

### Bug Fixes

- Restructure src
  ([`928a9c3`](https://github.com/celine-eu/ontologies/commit/928a9c3d7a41946913d4ff3bba242ab0bca42f70))


## v1.0.0 (2026-03-22)

- Initial Release
